#!/usr/bin/perl -I/usr/sausalito/perl
# $Id: set_ostemplates_conf.pl, v1.0.0-1 Fri 30 Oct 2009 09:15:58 PM CET mstauber Exp $
# Copyright 2006-2012 Solarspeed.net. All rights reserved.
# Copyright 2010-2011 Bluapp AB. All rights reserved.

# Constructor that checks if this cluster node is primary or secondary. Based on that
# it enables or disables the OS-Templates YUM repository for this node.

# Debugging switch:
$DEBUG = "0";

$whatami = "constructor";

# Location of Repository files:
$repo_ost_cf = "/etc/yum.repos.d/Aventurin-OS-Templates.repo";

# Check status of /vz to see if it is mounted:
$vz_status_direct = `/bin/mount | /bin/grep "/dev/mapper/sysvg-vz on /vz" | /usr/bin/wc -l`;
$vz_status_indirect = `/bin/mount | /bin/grep "/dev/drbd0 on /vz" | /usr/bin/wc -l`;
chomp($vz_status_direct);
chomp($vz_status_indirect);
$vz_status = 0;
if (($vz_status_direct == "1") || ($vz_status_indirect == "1")) {
        $vz_status = 1;
}
if (-e "/proc/drbd") {
	$is_cluster = "1";
}
else {
	$is_cluster = "0";
}
if ($DEBUG == "1") { print "/vz mount status: $vz_status \n"; }

#
#### No configureable options below!
#

@repo_files = ("$repo_ost_cf");

use CCE;
use Data::Dumper;

my $cce = new CCE;

if ($whatami eq "handler") {
    $cce->connectfd();
}
else {
    $cce->connectuds();
}

# Loop through the config files:
foreach $config (@repo_files) {

    # Config file present?
    if (-f $config) {

        # Read, parse and hash config:
        &ini_read;

        # Shove ouput into CCE:
        &feedthemonster;
    }
    else {
        # Ok, we have a problem: No config found.
        # So we just weep silently and exit. 
        $cce->bye('FAIL', "$config not found!");
        exit(1);
    }
}

$cce->bye('SUCCESS');
exit(0);

# Read and parse config:
sub ini_read {
    open (F, $config) || die "Could not open $config: $!";

    while ($line = <F>) {
        chomp($line);
        next if $line =~ /^\s*$/;                       # skip blank lines
        next if $line =~ /^\#*$/;                       # skip comment lines
        if ($line =~ /^([A-Za-z_\.]\w*)/) {
            $line =~s/\s//g;                            # Remove spaces
            $line =~s/#(.*)$//g;                        # Remove trailing comments in lines
            $line =~s/\"//g;                            # Remove double quotation marks

            @row = split (/=/, $line);                  # Split row at the equal sign. Unfortunately if there are more than one
            $CONFIG{$row[0]} = $row[1];                 # Build our config Hash
        }
    }
    close(F);

    # At this point we have all switches from config cleanly in a hash, split in key / value pairs.
    # To read how "user_rule" is set we query $CONFIG{'user_rule'} for example. 

    # For debugging only:
    if ($DEBUG == "1") {
        print "DEBUG: $config " . $CONFIG{'enabled'} . "\n";
    }
}

sub feedthemonster {
    @oids = $cce->find('System');
    if ($#oids < 0) {
        # Object not yet in CCE. Skipping for now and operating with schema defaults.
        $cce->bye('SUCCESS');
        exit(0);
    }
    else {
        # Object already present in CCE. Updating it.
        ($sys_oid) = $cce->find('System');
        ($ok, $sys) = $cce->get($sys_oid, "yum");
        
        # If /vz is mounted, user wants OST enabled, then enable it again:
        if (($sys->{repo_ost_userwish} == "1") && ($vz_status == "1") && ($is_cluster == "1")) {
            $CONFIG{'enabled'} = "1";
        }
        # If the config says OST repo enabled, but /vz is not mounted, then disable the OST repo:
        if (($CONFIG{'enabled'} == "1") && ($vz_status == "0") && ($is_cluster == "1")) {
            $CONFIG{'enabled'} = "0";
        }

        if ($config eq $repo_ost_cf) {
            $repo = "repo_ost";
        }

        # For debugging only:
        if ($DEBUG == "1") {
                print "Repo: $repo - " . $CONFIG{"enabled"} .  "\n";
        }

        ($ok) = $cce->set($sys_oid, 'yum',{
            $repo => $CONFIG{"enabled"}  
        });
    }
}

$cce->bye('SUCCESS');
exit(0);
